package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbStudyCenterFile;

import java.util.List;

/**
 * 学习中心文件Service接口
 *
 * @author ruoyi
 * @date 2024-11-18
 */
public interface ITbStudyCenterFileService
{
    /**
     * 查询学习中心文件
     *
     * @param studyCenterFileId 学习中心文件主键
     * @return 学习中心文件
     */
    public TbStudyCenterFile selectTbStudyCenterFileByStudyCenterFileId(Long studyCenterFileId);

    /**
     * 查询学习中心文件列表
     *
     * @param tbStudyCenterFile 学习中心文件
     * @return 学习中心文件集合
     */
    public List<TbStudyCenterFile> selectTbStudyCenterFileList(TbStudyCenterFile tbStudyCenterFile);

    /**
     * 新增学习中心文件
     *
     * @param tbStudyCenterFile 学习中心文件
     * @return 结果
     */
    public int insertTbStudyCenterFile(TbStudyCenterFile tbStudyCenterFile);

    /**
     * 修改学习中心文件
     *
     * @param tbStudyCenterFile 学习中心文件
     * @return 结果
     */
    public int updateTbStudyCenterFile(TbStudyCenterFile tbStudyCenterFile);

    /**
     * 批量删除学习中心文件
     *
     * @param studyCenterFileIds 需要删除的学习中心文件主键集合
     * @return 结果
     */
    public int deleteTbStudyCenterFileByStudyCenterFileIds(Long[] studyCenterFileIds);

    /**
     * 删除学习中心文件信息
     *
     * @param studyCenterFileId 学习中心文件主键
     * @return 结果
     */
    public int deleteTbStudyCenterFileByStudyCenterFileId(Long studyCenterFileId);
}
